@@ -265,8 +265,8 @@ ephy_file (const char *filename)
 /**
  * ephy_dot_dir:
  *
- * Gets Epiphany's configuration directory, usually .gnome2/epiphany under
- * user's homedir.
+ * Gets Epiphany's configuration directory, usually .config/epiphany
+ * under user's homedir.
  *
  * Returns: the full path to Epiphany's configuration directory
  **/
@@ -1011,8 +1011,9 @@ ephy_file_delete_uri (const char *uri)
  * Returns: a new allocated string containg the data uri, or %NULL if the
  *   data uri could not be created
  */
-char *ephy_file_create_data_uri_for_filename (const char *filename,
-					      const char *mime_type)
+char *
+ephy_file_create_data_uri_for_filename (const char *filename,
+					const char *mime_type)
 {
 	gchar *data;
 	gsize data_length;
@@ -1049,3 +1050,24 @@ char *ephy_file_create_data_uri_for_filename (const char *filename,
 
 	return uri;
 }
+
+/**
+ * ephy_sanitize_filename:
+ * @filename: a filename
+ *
+ * Sanitize @filename to make sure it's a valid filename. If the
+ * filename contains directory separators, they will be converted to
+ * underscores, so that they are not interpreted as a path by the
+ * filesystem.
+ *
+ * Note that it modifies string in place. The return value is to allow nesting.
+ *
+ * Returns: the sanitized filename
+ */
+char *
+ephy_sanitize_filename (char *filename)
+{
+	g_return_val_if_fail (filename != NULL, NULL);
+
+	return g_strdelimit (filename, G_DIR_SEPARATOR_S, '_');
+}
