@@ -20,10 +20,11 @@
  */
 
 #include "config.h"
+#include "ephy-profile-utils.h"
 
 #include "ephy-debug.h"
 #include "ephy-file-helpers.h"
-#include "ephy-profile-utils.h"
+
 #include <libsoup/soup.h>
 
 #define PROFILE_MIGRATION_FILE ".migrated"
@@ -50,6 +51,14 @@ ephy_profile_utils_get_migration_version ()
 
     if (result != 1)
       latest = 0;
+  } else if (ephy_dot_dir_is_default () == FALSE) {
+    /* Since version 8, we need to migrate also profile directories
+       other than the default one. Profiles in such directories work
+       perfectly fine without going through the first 7 migration
+       steps, so it is safe to assume that any non-default profile
+       directory without a migration file can be migrated starting
+       from the step 8. */
+    latest = 7;
   }
 
   g_free (migrated_file);
@@ -191,25 +200,32 @@ _ephy_profile_utils_query_form_auth_data (const char *uri,
 #define EPHY_PROFILE_MIGRATOR "ephy-profile-migrator"
 
 gboolean
-ephy_profile_utils_do_migration (int test_to_run, gboolean debug)
+ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run, gboolean debug)
 {
   gboolean ret;
   GError *error = NULL;
-  char *index = NULL;
+  char *index = NULL, *version = NULL;
   int status;
-  char *argv[3] = { EPHY_PROFILE_MIGRATOR };
+  char *argv[6] = { EPHY_PROFILE_MIGRATOR, "-v" };
+  int i = 2; /* index for argv, start filling at 2. */
   char *envp[1] = { "EPHY_LOG_MODULES=ephy-profile" };
 
+  argv[i++] = version = g_strdup_printf ("%d", EPHY_PROFILE_MIGRATION_VERSION);
+
   if (test_to_run != -1) {
     index = g_strdup_printf ("%d", test_to_run);
 
-    argv[1] = "-d";
-    argv[2] = index;
-    argv[3] = NULL;
-  } else {
-    argv[1] = NULL;
+    argv[i++] = "-d";
+    argv[i++] = index;
   }
 
+  if (profile_directory != NULL) {
+    argv[i++] = "-p";
+    argv[i++] = (char *)profile_directory;
+  }
+
+  argv[i++] = NULL;
+
   if (debug)
     argv[0] = ABS_TOP_BUILD_DIR"/lib/"EPHY_PROFILE_MIGRATOR;
 
@@ -217,6 +233,7 @@ ephy_profile_utils_do_migration (int test_to_run, gboolean debug)
                       NULL, NULL, NULL, NULL,
                       &status, &error);
   g_free (index);
+  g_free (version);
     
   if (error) {
     LOG ("Failed to run migrator: %s", error->message);
