@@ -22,30 +22,22 @@
  */
 
 #include "config.h"
-
 #include "ephy-extensions-manager.h"
 
-#include "ephy-loader.h"
-#include "ephy-shlib-loader.h"
-
-#include "ephy-embed-container.h"
-
-#include "ephy-node-db.h"
-#include "ephy-shell.h"
-#include "ephy-file-helpers.h"
-#include "ephy-object-helpers.h"
 #include "ephy-debug.h"
+#include "ephy-embed-container.h"
+#include "ephy-file-helpers.h"
+#include "ephy-loader.h"
+#include "ephy-object-helpers.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
+#include "ephy-shell.h"
+#include "ephy-shlib-loader.h"
 
 #include <gio/gio.h>
 #include <gmodule.h>
 #include <string.h>
 
-#ifdef ENABLE_SEED
-#include "ephy-seed-loader.h"
-#endif
-
 #define EE_GROUP		"Epiphany Extension"
 #define DOT_INI			".ephy-extension"
 #define RELOAD_DELAY		333 /* ms */
@@ -451,25 +443,12 @@ get_loader_for_type (EphyExtensionsManager *manager,
 
 		return g_object_ref (info->loader);
 	}
-	if (strcmp (type, "python") == 0)
+	if (strcmp (type, "python") == 0 ||
+	    strcmp (type, "seed") == 0)
 	{
 		return NULL;
 	}
 
-#ifdef ENABLE_SEED
-	if (strcmp (type, "seed") == 0)
-	{
-		info = g_new (LoaderInfo, 1);
-		info->type = g_strdup (type);
-		info->loader = g_object_new (EPHY_TYPE_SEED_LOADER, NULL);
-
-		manager->priv->factories =
-				g_list_append (manager->priv->factories, info);
-
-		return g_object_ref (info->loader);
-		return NULL;
-	}
-#endif
 	shlib_loader = get_loader_for_type (manager, "shlib");
 	g_return_val_if_fail (shlib_loader != NULL, NULL);
 
