@@ -311,6 +311,7 @@ session_command_open_uris (EphySession *session,
 	EphySessionPrivate *priv;
 	EphyNewTabFlags flags = 0;
 	guint i;
+	gboolean new_windows_in_tabs;
 
 	priv = session->priv;
 
@@ -320,6 +321,9 @@ session_command_open_uris (EphySession *session,
 
 	window = ephy_session_get_active_window (session);
 
+	new_windows_in_tabs = g_settings_get_boolean (EPHY_SETTINGS_MAIN,
+						      EPHY_PREFS_NEW_WINDOWS_IN_TABS);
+
 	if (options != NULL && strstr (options, "external") != NULL)
 	{
 		flags |= EPHY_NEW_TAB_FROM_EXTERNAL;
@@ -329,10 +333,12 @@ session_command_open_uris (EphySession *session,
 		window = NULL;
 		flags |= EPHY_NEW_TAB_IN_NEW_WINDOW;
 	}
-	else if (options != NULL && strstr (options, "new-tab") != NULL)
+	else if ((options != NULL && strstr (options, "new-tab") != NULL) ||
+		 new_windows_in_tabs)
 	{
 		flags |= EPHY_NEW_TAB_IN_EXISTING_WINDOW |
-			 EPHY_NEW_TAB_JUMP;
+			 EPHY_NEW_TAB_JUMP |
+			 EPHY_NEW_TAB_PRESENT_WINDOW;
 	}
 
 	for (i = 0; uris[i] != NULL; ++i)
@@ -963,6 +969,9 @@ parse_embed (xmlNodePtr child,
 				xmlChar* title = xmlGetProp (child, (const xmlChar *) "title");
 			
 				confirm_before_recover (window, (char*) url, (char*) title);
+
+				if (title)
+					xmlFree (title);
 			}
 
 			xmlFree (url);
